function pressure = pressure(volume,temperature)
% pressure computes pressure of a gas given volume and temperature
% assuming constant moles
%
% consumes: 
%     volume: number, volume of gas in cubic meters
%     temperature: number, temperature of gas in Kelvin
% produces:
%     pressure: number, pressure of gas in Pascals
%     
% examples
%     >> pressure(10,100)
%     ans = 83.14472
%     >> pressure(72,300)
%     ans = 34.64363333
%     
% Dylan Kee 9/11/07 CISC106 Section 080
  
  pressure = (8.314472 * temperature)/volume;
  return;
  
end % function
